.. _user_guide:

==========
User Guide
==========

.. .. include:: ../../../README.md
..    :parser: myst_parser.sphinx_

The user guide provides a practical tutorial for the :ref:`installation<user_guide_installation>` of the python environnement and dependencies, 
a :ref:`quick_start<user_guide_quick_start>` guide to run the model and small example for the :ref:`data visualization<user_guide_data_visualization>`.

.. toctree::
   :maxdepth: 2

   installation
   quick_start
   data_visualization


